@@ -31,14 +31,11 @@
   const_fn,
   const_fn_union,
   const_generics,
-  const_if_match,
-  const_loop,
   const_mut_refs,
   const_panic,
   const_ptr_offset_from,
   const_raw_ptr_deref,
   const_raw_ptr_to_usize_cast,
-  const_saturating_int_methods,
   const_trait_impl,
   core_intrinsics,
   doc_cfg,
